"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def authorize(
    hub,
    ctx,
    group_id: str,
    dry_run: bool = None,
    ip_permissions: List = None,
    tag_specifications: List = None,
    cidr_ip: str = None,
    from_port: int = None,
    ip_protocol: str = None,
    to_port: int = None,
    source_security_group_name: str = None,
    source_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    [VPC only] Adds the specified outbound (egress) rules to a security group for use with a VPC. An outbound rule permits instances to send traffic to the specified IPv4 or IPv6 CIDR address ranges, or to the instances that are associated with the specified destination security groups. You specify a protocol for each rule (for example, TCP). For the TCP and UDP protocols, you must also specify the destination port or port range. For the ICMP protocol, you must also specify the ICMP type and code. You can use -1 for the type or code to mean all types or all codes. Rule changes are propagated to affected instances as quickly as possible. However, a small delay might occur. For information about VPC security group quotas, see Amazon VPC quotas.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_id(str): The ID of the security group.
        ip_permissions(List, optional): The sets of IP permissions. You can't specify a destination security group and a CIDR IP address range in the same set of permissions. Defaults to None.
        tag_specifications(List, optional): The tags applied to the security group rule. Defaults to None.
        cidr_ip(str, optional): Not supported. Use a set of IP permissions to specify the CIDR. Defaults to None.
        from_port(int, optional): Not supported. Use a set of IP permissions to specify the port. Defaults to None.
        ip_protocol(str, optional): Not supported. Use a set of IP permissions to specify the protocol name or number. Defaults to None.
        to_port(int, optional): Not supported. Use a set of IP permissions to specify the port. Defaults to None.
        source_security_group_name(str, optional): Not supported. Use a set of IP permissions to specify a destination security group. Defaults to None.
        source_security_group_owner_id(str, optional): Not supported. Use a set of IP permissions to specify a destination security group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.egress.authorize(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.egress.authorize group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="authorize_security_group_egress",
        op_kwargs={
            "DryRun": dry_run,
            "GroupId": group_id,
            "IpPermissions": ip_permissions,
            "TagSpecifications": tag_specifications,
            "CidrIp": cidr_ip,
            "FromPort": from_port,
            "IpProtocol": ip_protocol,
            "ToPort": to_port,
            "SourceSecurityGroupName": source_security_group_name,
            "SourceSecurityGroupOwnerId": source_security_group_owner_id,
        },
    )


async def revoke(
    hub,
    ctx,
    group_id: str,
    dry_run: bool = None,
    ip_permissions: List = None,
    security_group_rule_ids: List = None,
    cidr_ip: str = None,
    from_port: int = None,
    ip_protocol: str = None,
    to_port: int = None,
    source_security_group_name: str = None,
    source_security_group_owner_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    [VPC only] Removes the specified outbound (egress) rules from a security group for EC2-VPC. This action does not apply to security groups for use in EC2-Classic. You can specify rules using either rule IDs or security group rule properties. If you use rule properties, the values that you specify (for example, ports) must match the existing rule's values exactly. Each rule has a protocol, from and to ports, and destination (CIDR range, security group, or prefix list). For the TCP and UDP protocols, you must also specify the destination port or range of ports. For the ICMP protocol, you must also specify the ICMP type and code. If the security group rule has a description, you do not need to specify the description to revoke the rule. [Default VPC] If the values you specify do not match the existing rule's values, no error is returned, and the output describes the security group rules that were not revoked. Amazon Web Services recommends that you describe the security group to verify that the rules were removed. Rule changes are propagated to instances within the security group as quickly as possible. However, a small delay might occur.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        group_id(str): The ID of the security group.
        ip_permissions(List, optional): The sets of IP permissions. You can't specify a destination security group and a CIDR IP address range in the same set of permissions. Defaults to None.
        security_group_rule_ids(List, optional): The IDs of the security group rules. Defaults to None.
        cidr_ip(str, optional): Not supported. Use a set of IP permissions to specify the CIDR. Defaults to None.
        from_port(int, optional): Not supported. Use a set of IP permissions to specify the port. Defaults to None.
        ip_protocol(str, optional): Not supported. Use a set of IP permissions to specify the protocol name or number. Defaults to None.
        to_port(int, optional): Not supported. Use a set of IP permissions to specify the port. Defaults to None.
        source_security_group_name(str, optional): Not supported. Use a set of IP permissions to specify a destination security group. Defaults to None.
        source_security_group_owner_id(str, optional): Not supported. Use a set of IP permissions to specify a destination security group. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.security_group.egress.revoke(ctx, group_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.security_group.egress.revoke group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="revoke_security_group_egress",
        op_kwargs={
            "DryRun": dry_run,
            "GroupId": group_id,
            "IpPermissions": ip_permissions,
            "SecurityGroupRuleIds": security_group_rule_ids,
            "CidrIp": cidr_ip,
            "FromPort": from_port,
            "IpProtocol": ip_protocol,
            "ToPort": to_port,
            "SourceSecurityGroupName": source_security_group_name,
            "SourceSecurityGroupOwnerId": source_security_group_owner_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__virtualname__ = "to_set"


async def add(hub, ctx, attachments: List, attachment_set_id: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more attachments to an attachment set.  An attachment set is a temporary container for attachments that you add to a case or case communication. The set is available for 1 hour after it's created. The expiryTime returned in the response is when the set expires.     You must have a Business or Enterprise Support plan to use the AWS Support API.    If you call the AWS Support API from an account that does not have a Business or Enterprise Support plan, the SubscriptionRequiredException error message appears. For information about changing your support plan, see AWS Support.

    Args:
        attachment_set_id(str, optional): The ID of the attachment set. If an attachmentSetId is not specified, a new attachment set is created, and the ID of the set is returned in the response. If an attachmentSetId is specified, the attachments are added to the specified set, if it exists. Defaults to None.
        attachments(List): One or more attachments to add to the set. You can add up to three attachments per set. The size limit is 5 MB per attachment. In the Attachment object, use the data parameter to specify the contents of the attachment file. In the previous request syntax, the value for data appear as blob, which is represented as a base64-encoded string. The value for fileName is the name of the attachment, such as troubleshoot-screenshot.png.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.support.attachment.to_set_.add(ctx, attachments=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.support.attachment.to_set.add attachments=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="support",
        operation="add_attachments_to_set",
        op_kwargs={"attachmentSetId": attachment_set_id, "attachments": attachments},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    filters: List = None,
    vpc_ids: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your VPCs.

    Args:
        filters(List, optional): One or more filters.    cidr - The primary IPv4 CIDR block of the VPC. The CIDR block you specify must exactly match the VPC's CIDR block for information to be returned for the VPC. Must contain the slash followed by one or two digits (for example, /28).    cidr-block-association.cidr-block - An IPv4 CIDR block associated with the VPC.    cidr-block-association.association-id - The association ID for an IPv4 CIDR block associated with the VPC.    cidr-block-association.state - The state of an IPv4 CIDR block associated with the VPC.    dhcp-options-id - The ID of a set of DHCP options.    ipv6-cidr-block-association.ipv6-cidr-block - An IPv6 CIDR block associated with the VPC.    ipv6-cidr-block-association.ipv6-pool - The ID of the IPv6 address pool from which the IPv6 CIDR block is allocated.    ipv6-cidr-block-association.association-id - The association ID for an IPv6 CIDR block associated with the VPC.    ipv6-cidr-block-association.state - The state of an IPv6 CIDR block associated with the VPC.    is-default - Indicates whether the VPC is the default VPC.    owner-id - The ID of the Amazon Web Services account that owns the VPC.    state - The state of the VPC (pending | available).    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC.  . Defaults to None.
        vpc_ids(List, optional): One or more VPC IDs. Default: Describes all your VPCs. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.vpcs.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.vpcs.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_vpcs",
        op_kwargs={
            "Filters": filters,
            "VpcIds": vpc_ids,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def get(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns the current data retrieval policy for the account and region specified in the GET request. For more information about data retrieval policies, see Amazon Glacier Data Retrieval Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens ('-') in the ID. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.data_retrieval_policy.get(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.data_retrieval_policy.get account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="get_data_retrieval_policy",
        op_kwargs={"accountId": account_id},
    )


async def set_(hub, ctx, account_id: str, policy: Dict = None) -> None:
    r"""
    **Autogenerated function**

    This operation sets and then enacts a data retrieval policy in the region specified in the PUT request. You can set one policy per region for an AWS account. The policy is enacted within a few minutes of a successful PUT operation. The set policy operation does not affect retrieval jobs that were in progress before the policy was enacted. For more information about data retrieval policies, see Amazon Glacier Data Retrieval Policies.

    Args:
        account_id(str): The AccountId value is the AWS account ID. This value must match the AWS account ID associated with the credentials used to sign the request. You can either specify an AWS account ID or optionally a single '-' (hyphen), in which case Amazon Glacier uses the AWS account ID associated with the credentials used to sign the request. If you specify your account ID, do not include any hyphens ('-') in the ID.
        policy(Dict, optional): The data retrieval policy in JSON format. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.glacier.data_retrieval_policy.set(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.glacier.data_retrieval_policy.set account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="glacier",
        operation="set_data_retrieval_policy",
        op_kwargs={"accountId": account_id, "Policy": policy},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, skill_group_arn: str = None, room_arn: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a skill group from a specified room. This disables all skills in the skill group on all devices in the room.

    Args:
        skill_group_arn(str, optional): The ARN of the skill group to disassociate from a room. Required. Defaults to None.
        room_arn(str, optional): The ARN of the room from which the skill group is to be disassociated. Required. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.alexaforbusiness.skill.group.from_room.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.alexaforbusiness.skill.group.from_room.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="alexaforbusiness",
        operation="disassociate_skill_group_from_room",
        op_kwargs={"SkillGroupArn": skill_group_arn, "RoomArn": room_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    mesh_name: str,
    client_token: str = None,
    spec: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a service mesh.  A service mesh is a logical boundary for network traffic between services that are represented by resources within the mesh. After you create your service mesh, you can create virtual services, virtual nodes, virtual routers, and routes to distribute traffic between the applications in your mesh. For more information about service meshes, see Service meshes.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name to use for the service mesh.
        spec(Dict, optional): The service mesh specification to apply. Defaults to None.
        tags(List, optional): Optional metadata that you can apply to the service mesh to assist with categorization and organization. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.mesh.create(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.mesh.create mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="create_mesh",
        op_kwargs={
            "clientToken": client_token,
            "meshName": mesh_name,
            "spec": spec,
            "tags": tags,
        },
    )


async def delete(hub, ctx, mesh_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing service mesh. You must delete all resources (virtual services, routes, virtual routers, and virtual nodes) in the service mesh before you can delete the mesh itself.

    Args:
        mesh_name(str): The name of the service mesh to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.mesh.delete(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.mesh.delete mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="delete_mesh",
        op_kwargs={"meshName": mesh_name},
    )


async def describe(hub, ctx, mesh_name: str, mesh_owner: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes an existing service mesh.

    Args:
        mesh_name(str): The name of the service mesh to describe.
        mesh_owner(str, optional): The AWS IAM account ID of the service mesh owner. If the account ID is not your own, then it's the ID of the account that shared the mesh with your account. For more information about mesh sharing, see Working with shared meshes. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.mesh.describe(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.mesh.describe mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="describe_mesh",
        op_kwargs={"meshName": mesh_name, "meshOwner": mesh_owner},
    )


async def list_all(hub, ctx, limit: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of existing service meshes.

    Args:
        limit(int, optional): The maximum number of results returned by ListMeshes in paginated output. When you use this parameter, ListMeshes returns only limit results in a single page along with a nextToken response element. You can see the remaining results of the initial request by sending another ListMeshes request with the returned nextToken value. This value can be between 1 and 100. If you don't use this parameter, ListMeshes returns up to 100 results and a nextToken value if applicable. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListMeshes request where limit was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.  This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.mesh.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.mesh.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="list_meshes",
        op_kwargs={"limit": limit, "nextToken": next_token},
    )


async def update(
    hub, ctx, mesh_name: str, client_token: str = None, spec: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing service mesh.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. Up to 36 letters, numbers, hyphens, and underscores are allowed. Defaults to None.
        mesh_name(str): The name of the service mesh to update.
        spec(Dict, optional): The service mesh specification to apply. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appmesh.mesh.update(ctx, mesh_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appmesh.mesh.update mesh_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appmesh",
        operation="update_mesh",
        op_kwargs={"clientToken": client_token, "meshName": mesh_name, "spec": spec},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a default VPC with a size /16 IPv4 CIDR block and a default subnet in each Availability Zone. For more information about the components of a default VPC, see Default VPC and default subnets in the Amazon Virtual Private Cloud User Guide. You cannot specify the components of the default VPC yourself. If you deleted your previous default VPC, you can create a default VPC. You cannot have more than one default VPC per Region. If your account supports EC2-Classic, you cannot use this action to create a default VPC in a Region that supports EC2-Classic. If you want a default VPC in a Region that supports EC2-Classic, see "I really want a default VPC for my existing EC2 account. Is that possible?" in the Default VPCs FAQ.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.default.vpc.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.default.vpc.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_default_vpc",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def disable(hub, ctx, auto_scaling_group_name: str, metrics: List = None) -> None:
    r"""
    **Autogenerated function**

    Disables group metrics for the specified Auto Scaling group.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        metrics(List, optional): Specifies one or more of the following metrics:    GroupMinSize     GroupMaxSize     GroupDesiredCapacity     GroupInServiceInstances     GroupPendingInstances     GroupStandbyInstances     GroupTerminatingInstances     GroupTotalInstances     GroupInServiceCapacity     GroupPendingCapacity     GroupStandbyCapacity     GroupTerminatingCapacity     GroupTotalCapacity     WarmPoolDesiredCapacity     WarmPoolWarmedCapacity     WarmPoolPendingCapacity     WarmPoolTerminatingCapacity     WarmPoolTotalCapacity     GroupAndWarmPoolDesiredCapacity     GroupAndWarmPoolTotalCapacity    If you omit this parameter, all metrics are disabled. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.metric_collection.init.disable(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.metric_collection.init.disable auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="disable_metrics_collection",
        op_kwargs={"AutoScalingGroupName": auto_scaling_group_name, "Metrics": metrics},
    )


async def enable(
    hub, ctx, auto_scaling_group_name: str, granularity: str, metrics: List = None
) -> None:
    r"""
    **Autogenerated function**

    Enables group metrics for the specified Auto Scaling group. For more information, see Monitoring CloudWatch metrics for your Auto Scaling groups and instances in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        metrics(List, optional): Specifies which group-level metrics to start collecting. You can specify one or more of the following metrics:    GroupMinSize     GroupMaxSize     GroupDesiredCapacity     GroupInServiceInstances     GroupPendingInstances     GroupStandbyInstances     GroupTerminatingInstances     GroupTotalInstances    The instance weighting feature supports the following additional metrics:     GroupInServiceCapacity     GroupPendingCapacity     GroupStandbyCapacity     GroupTerminatingCapacity     GroupTotalCapacity    The warm pools feature supports the following additional metrics:     WarmPoolDesiredCapacity     WarmPoolWarmedCapacity     WarmPoolPendingCapacity     WarmPoolTerminatingCapacity     WarmPoolTotalCapacity     GroupAndWarmPoolDesiredCapacity     GroupAndWarmPoolTotalCapacity    If you omit this parameter, all metrics are enabled. . Defaults to None.
        granularity(str): The granularity to associate with the metrics to collect. The only valid value is 1Minute.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.metric_collection.init.enable(
                ctx, auto_scaling_group_name=value, granularity=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.metric_collection.init.enable auto_scaling_group_name=value, granularity=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="enable_metrics_collection",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "Metrics": metrics,
            "Granularity": granularity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete_multiple(hub, ctx, bot_name: str, user_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes stored utterances. Amazon Lex stores the utterances that users send to your bot. Utterances are stored for 15 days for use with the GetUtterancesView operation, and then stored indefinitely for use in improving the ability of your bot to respond to user input. Use the DeleteUtterances operation to manually delete stored utterances for a specific user. When you use the DeleteUtterances operation, utterances stored for improving your bot's ability to respond to user input are deleted immediately. Utterances stored for use with the GetUtterancesView operation are deleted after 15 days. This operation requires permissions for the lex:DeleteUtterances action.

    Args:
        bot_name(str): The name of the bot that stored the utterances.
        user_id(str):  The unique identifier for the user that made the utterances. This is the user ID that was sent in the PostContent or PostText operation request that contained the utterance.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.utterance.init.delete_multiple(
                ctx, bot_name=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.utterance.init.delete_multiple bot_name=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_utterances",
        op_kwargs={"botName": bot_name, "userId": user_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Associates your quota request template with your organization. When a new account is created in your organization, the quota increase requests in the template are automatically applied to the account. You can add a quota increase request for any adjustable quota to your template.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.template.associate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.template.associate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="associate_service_quota_template",
        op_kwargs={},
    )


async def disassociate(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disables your quota request template. After a template is disabled, the quota increase requests in the template are not applied to new accounts in your organization. Disabling a quota request template does not apply its quota increase requests.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.service_quotas.service.quota.template.disassociate(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.service_quotas.service.quota.template.disassociate
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="service-quotas",
        operation="disassociate_service_quota_template",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, account_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves account settings for the specified Amazon Chime account ID, such as remote control and dialout settings. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.

    Args:
        account_id(str): The Amazon Chime account ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.setting.get_all(ctx, account_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.setting.get_all account_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_account_settings",
        op_kwargs={"AccountId": account_id},
    )


async def update_multiple(hub, ctx, account_id: str, account_settings: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates the settings for the specified Amazon Chime account. You can update settings for remote control of shared screens, or for the dial-out option. For more information about these settings, see Use the Policies Page in the Amazon Chime Administration Guide.

    Args:
        account_id(str): The Amazon Chime account ID.
        account_settings(Dict): The Amazon Chime account settings to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.account.setting.update_multiple(
                ctx, account_id=value, account_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.account.setting.update_multiple account_id=value, account_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_account_settings",
        op_kwargs={"AccountId": account_id, "AccountSettings": account_settings},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def stop(hub, ctx, contact_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Ends the specified contact.

    Args:
        contact_id(str): The ID of the contact.
        instance_id(str): The identifier of the Amazon Connect instance. You can find the instanceId in the ARN of the instance.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.connect.contact.init.stop(
                ctx, contact_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.connect.contact.init.stop contact_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="connect",
        operation="stop_contact",
        op_kwargs={"ContactId": contact_id, "InstanceId": instance_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, config_rule_name: str, resource_type: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the remediation configuration.

    Args:
        config_rule_name(str): The name of the AWS Config rule for which you want to delete remediation configuration.
        resource_type(str, optional): The type of a resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.configuration.delete(
                ctx, config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.configuration.delete config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="delete_remediation_configuration",
        op_kwargs={"ConfigRuleName": config_rule_name, "ResourceType": resource_type},
    )


async def describe_all(hub, ctx, config_rule_names: List) -> Dict:
    r"""
    **Autogenerated function**

    Returns the details of one or more remediation configurations.

    Args:
        config_rule_names(List): A list of AWS Config rule names of remediation configurations for which you want details. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.configuration.describe_all(
                ctx, config_rule_names=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.configuration.describe_all config_rule_names=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_remediation_configurations",
        op_kwargs={"ConfigRuleNames": config_rule_names},
    )


async def put_multiple(hub, ctx, remediation_configurations: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or updates the remediation configuration with a specific AWS Config rule with the selected target or action. The API creates the RemediationConfiguration object for the AWS Config rule. The AWS Config rule must already exist for you to add a remediation configuration. The target (SSM document) must exist and have permissions to use the target.   If you make backward incompatible changes to the SSM document, you must call this again to ensure the remediations can run. This API does not support adding remediation configurations for service-linked AWS Config Rules such as Organization Config rules, the rules deployed by conformance packs, and rules deployed by AWS Security Hub.

    Args:
        remediation_configurations(List): A list of remediation configuration objects.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.configuration.put_multiple(
                ctx, remediation_configurations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.configuration.put_multiple remediation_configurations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="put_remediation_configurations",
        op_kwargs={"RemediationConfigurations": remediation_configurations},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, task_token: str, output: str) -> Dict:
    r"""
    **Autogenerated function**

    Used by activity workers and task states using the callback pattern to report that the task identified by the taskToken completed successfully.

    Args:
        task_token(str): The token that represents this task. Task tokens are generated by Step Functions when tasks are assigned to a worker, or in the context object when a workflow enters a task state. See GetActivityTaskOutput$taskToken.
        output(str): The JSON output of the task. Length constraints apply to the payload size, and are expressed as bytes in UTF-8 encoding.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.stepfunction.task.success.send(
                ctx, task_token=value, output=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.stepfunction.task.success.send task_token=value, output=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="stepfunctions",
        operation="send_task_success",
        op_kwargs={"taskToken": task_token, "output": output},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def send(
    hub,
    ctx,
    original_message_id: str,
    bounce_sender: str,
    bounced_recipient_info_list: List,
    explanation: str = None,
    message_dsn: Dict = None,
    bounce_sender_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Generates and sends a bounce message to the sender of an email you received through Amazon SES. You can only use this API on an email up to 24 hours after you receive it.  You cannot use this API to send generic bounces for mail that was not received by Amazon SES.  For information about receiving email through Amazon SES, see the Amazon SES Developer Guide. You can execute this operation no more than once per second.

    Args:
        original_message_id(str): The message ID of the message to be bounced.
        bounce_sender(str): The address to use in the "From" header of the bounce message. This must be an identity that you have verified with Amazon SES.
        explanation(str, optional): Human-readable text for the bounce message to explain the failure. If not specified, the text will be auto-generated based on the bounced recipient information. Defaults to None.
        message_dsn(Dict, optional): Message-related DSN fields. If not specified, Amazon SES will choose the values. Defaults to None.
        bounced_recipient_info_list(List): A list of recipients of the bounced message, including the information required to create the Delivery Status Notifications (DSNs) for the recipients. You must specify at least one BouncedRecipientInfo in the list.
        bounce_sender_arn(str, optional): This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the address in the "From" header of the bounce. For more information about sending authorization, see the Amazon SES Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.bounce.send(
                ctx,
                original_message_id=value,
                bounce_sender=value,
                bounced_recipient_info_list=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.bounce.send original_message_id=value, bounce_sender=value, bounced_recipient_info_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="send_bounce",
        op_kwargs={
            "OriginalMessageId": original_message_id,
            "BounceSender": bounce_sender,
            "Explanation": explanation,
            "MessageDsn": message_dsn,
            "BouncedRecipientInfoList": bounced_recipient_info_list,
            "BounceSenderArn": bounce_sender_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, function_name: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of versions, with the version-specific configuration of each. Lambda returns up to 50 versions per call.

    Args:
        function_name(str): The name of the Lambda function.  Name formats     Function name - MyFunction.    Function ARN - arn:aws:lambda:us-west-2:123456789012:function:MyFunction.    Partial ARN - 123456789012:function:MyFunction.   The length constraint applies only to the full ARN. If you specify only the function name, it is limited to 64 characters in length.
        marker(str, optional): Specify the pagination token that's returned by a previous request to retrieve the next page of results. Defaults to None.
        max_items(int, optional): The maximum number of versions to return. Note that ListVersionsByFunction returns a maximum of 50 items in each response, even if you set the number higher. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lambda_.version.by_function.list(ctx, function_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lambda_.version.by_function.list function_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lambda",
        operation="list_versions_by_function",
        op_kwargs={
            "FunctionName": function_name,
            "Marker": marker,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def add(hub, ctx, resource_id: str, tags_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to a trail, up to a limit of 50. Overwrites an existing tag's value when a new value is specified for an existing tag key. Tag key names must be unique for a trail; you cannot have two keys with the same name but different values. If you specify a key without a value, the tag will be created with the specified key and a value of null. You can tag a trail that applies to all AWS Regions only from the Region in which the trail was created (also known as its home region).

    Args:
        resource_id(str): Specifies the ARN of the trail to which one or more tags will be added. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .
        tags_list(List, optional): Contains a list of CloudTrail tags, up to a limit of 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.tags.add(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.tags.add resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="add_tags",
        op_kwargs={"ResourceId": resource_id, "TagsList": tags_list},
    )


async def list_(hub, ctx, resource_id_list: List, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags for the trail in the current region.

    Args:
        resource_id_list(List): Specifies a list of trail ARNs whose tags will be listed. The list has a limit of 20 ARNs. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .
        next_token(str, optional): Reserved for future use. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.tags.list(ctx, resource_id_list=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.tags.list resource_id_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="list_tags",
        op_kwargs={"ResourceIdList": resource_id_list, "NextToken": next_token},
    )


async def remove(hub, ctx, resource_id: str, tags_list: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified tags from a trail.

    Args:
        resource_id(str): Specifies the ARN of the trail from which tags should be removed. The format of a trail ARN is:  arn:aws:cloudtrail:us-east-2:123456789012:trail/MyTrail .
        tags_list(List, optional): Specifies a list of tags to be removed. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudtrail.tags.remove(ctx, resource_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudtrail.tags.remove resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudtrail",
        operation="remove_tags",
        op_kwargs={"ResourceId": resource_id, "TagsList": tags_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def remove(hub, ctx, stream_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes tags from the specified Kinesis data stream. Removed tags are deleted and cannot be recovered after this operation successfully completes. If you specify a tag that does not exist, it is ignored.  RemoveTagsFromStream has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream.
        tag_keys(List): A list of tag keys. Each corresponding tag is removed from the stream.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.tags.from_stream.remove(
                ctx, stream_name=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.tags.from_stream.remove stream_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="remove_tags_from_stream",
        op_kwargs={"StreamName": stream_name, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def restore(
    hub,
    ctx,
    db_cluster_identifier: str,
    snapshot_identifier: str,
    engine: str,
    availability_zones: List = None,
    engine_version: str = None,
    port: int = None,
    db_subnet_group_name: str = None,
    database_name: str = None,
    option_group_name: str = None,
    vpc_security_group_ids: List = None,
    tags: List = None,
    kms_key_id: str = None,
    enable_iam_database_authentication: bool = None,
    enable_cloudwatch_logs_exports: List = None,
    db_cluster_parameter_group_name: str = None,
    deletion_protection: bool = None,
    copy_tags_to_snapshot: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new DB cluster from a DB snapshot or DB cluster snapshot. If a DB snapshot is specified, the target DB cluster is created from the source DB snapshot with a default configuration and default security group. If a DB cluster snapshot is specified, the target DB cluster is created from the source DB cluster restore point with the same configuration as the original source DB cluster, except that the new DB cluster is created with the default security group.

    Args:
        availability_zones(List, optional): Provides the list of EC2 Availability Zones that instances in the restored DB cluster can be created in. Defaults to None.
        db_cluster_identifier(str): The name of the DB cluster to create from the DB snapshot or DB cluster snapshot. This parameter isn't case-sensitive. Constraints:   Must contain from 1 to 63 letters, numbers, or hyphens   First character must be a letter   Cannot end with a hyphen or contain two consecutive hyphens   Example: my-snapshot-id .
        snapshot_identifier(str): The identifier for the DB snapshot or DB cluster snapshot to restore from. You can use either the name or the Amazon Resource Name (ARN) to specify a DB cluster snapshot. However, you can use only the ARN to specify a DB snapshot. Constraints:   Must match the identifier of an existing Snapshot.  .
        engine(str): The database engine to use for the new DB cluster. Default: The same as source Constraint: Must be compatible with the engine of the source.
        engine_version(str, optional): The version of the database engine to use for the new DB cluster. Defaults to None.
        port(int, optional): The port number on which the new DB cluster accepts connections. Constraints: Value must be 1150-65535  Default: The same port as the original DB cluster. Defaults to None.
        db_subnet_group_name(str, optional): The name of the DB subnet group to use for the new DB cluster. Constraints: If supplied, must match the name of an existing DBSubnetGroup. Example: mySubnetgroup . Defaults to None.
        database_name(str, optional): Not supported. Defaults to None.
        option_group_name(str, optional):  (Not supported by Neptune) . Defaults to None.
        vpc_security_group_ids(List, optional): A list of VPC security groups that the new DB cluster will belong to. Defaults to None.
        tags(List, optional): The tags to be assigned to the restored DB cluster. Defaults to None.
        kms_key_id(str, optional): The Amazon KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot. The KMS key identifier is the Amazon Resource Name (ARN) for the KMS encryption key. If you are restoring a DB cluster with the same Amazon account that owns the KMS encryption key used to encrypt the new DB cluster, then you can use the KMS key alias instead of the ARN for the KMS encryption key. If you do not specify a value for the KmsKeyId parameter, then the following will occur:   If the DB snapshot or DB cluster snapshot in SnapshotIdentifier is encrypted, then the restored DB cluster is encrypted using the KMS key that was used to encrypt the DB snapshot or DB cluster snapshot.   If the DB snapshot or DB cluster snapshot in SnapshotIdentifier is not encrypted, then the restored DB cluster is not encrypted.  . Defaults to None.
        enable_iam_database_authentication(bool, optional): True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false. Default: false . Defaults to None.
        enable_cloudwatch_logs_exports(List, optional): The list of logs that the restored DB cluster is to export to Amazon CloudWatch Logs. Defaults to None.
        db_cluster_parameter_group_name(str, optional): The name of the DB cluster parameter group to associate with the new DB cluster. Constraints:   If supplied, must match the name of an existing DBClusterParameterGroup.  . Defaults to None.
        deletion_protection(bool, optional): A value that indicates whether the DB cluster has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. . Defaults to None.
        copy_tags_to_snapshot(bool, optional):  If set to true, tags are copied to any snapshot of the restored DB cluster that is created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.neptune.db.cluster.from_snapshot.restore(
                ctx, db_cluster_identifier=value, snapshot_identifier=value, engine=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.neptune.db.cluster.from_snapshot.restore db_cluster_identifier=value, snapshot_identifier=value, engine=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="neptune",
        operation="restore_db_cluster_from_snapshot",
        op_kwargs={
            "AvailabilityZones": availability_zones,
            "DBClusterIdentifier": db_cluster_identifier,
            "SnapshotIdentifier": snapshot_identifier,
            "Engine": engine,
            "EngineVersion": engine_version,
            "Port": port,
            "DBSubnetGroupName": db_subnet_group_name,
            "DatabaseName": database_name,
            "OptionGroupName": option_group_name,
            "VpcSecurityGroupIds": vpc_security_group_ids,
            "Tags": tags,
            "KmsKeyId": kms_key_id,
            "EnableIAMDatabaseAuthentication": enable_iam_database_authentication,
            "EnableCloudwatchLogsExports": enable_cloudwatch_logs_exports,
            "DBClusterParameterGroupName": db_cluster_parameter_group_name,
            "DeletionProtection": deletion_protection,
            "CopyTagsToSnapshot": copy_tags_to_snapshot,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    meeting_id: str,
    from_phone_number: str,
    to_phone_number: str,
    join_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Uses the join token and call metadata in a meeting request (From number, To number, and so forth) to initiate an outbound call to a public switched telephone network (PSTN) and join them into a Chime meeting. Also ensures that the From number belongs to the customer. To play welcome audio or implement an interactive voice response (IVR), use the CreateSipMediaApplicationCall action with the corresponding SIP media application ID.

    Args:
        meeting_id(str): The Amazon Chime SDK meeting ID.
        from_phone_number(str): Phone number used as the caller ID when the remote party receives a call.
        to_phone_number(str): Phone number called when inviting someone to a meeting.
        join_token(str): Token used by the Amazon Chime SDK attendee. Call the CreateAttendee action to get a join token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.meeting.dial_out.create(
                ctx,
                meeting_id=value,
                from_phone_number=value,
                to_phone_number=value,
                join_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.meeting.dial_out.create meeting_id=value, from_phone_number=value, to_phone_number=value, join_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="create_meeting_dial_out",
        op_kwargs={
            "MeetingId": meeting_id,
            "FromPhoneNumber": from_phone_number,
            "ToPhoneNumber": to_phone_number,
            "JoinToken": join_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables the email channel for an application and deletes any existing settings for the channel.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.email.channel.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.email.channel.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_email_channel",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the status and settings of the email channel for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.email.channel.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.email.channel.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_email_channel",
        op_kwargs={"ApplicationId": application_id},
    )


async def update(hub, ctx, application_id: str, email_channel_request: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables the email channel for an application or updates the status and settings of the email channel for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        email_channel_request(Dict): Specifies the status and settings of the email channel for an application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.email.channel.update(
                ctx, application_id=value, email_channel_request=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.email.channel.update application_id=value, email_channel_request=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="update_email_channel",
        op_kwargs={
            "ApplicationId": application_id,
            "EmailChannelRequest": email_channel_request,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def delete_multiple(hub, ctx, arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a set of GitHub, GitHub Enterprise, or Bitbucket source credentials.

    Args:
        arn(str):  The Amazon Resource Name (ARN) of the token.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.source_credential.delete_multiple(ctx, arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.source_credential.delete_multiple arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="delete_source_credentials",
        op_kwargs={"arn": arn},
    )


async def import_(
    hub,
    ctx,
    token: str,
    server_type: str,
    auth_type: str,
    username: str = None,
    should_overwrite: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Imports the source repository credentials for an AWS CodeBuild project that has its source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository.

    Args:
        username(str, optional):  The Bitbucket username when the authType is BASIC_AUTH. This parameter is not valid for other types of source providers or connections. . Defaults to None.
        token(str):  For GitHub or GitHub Enterprise, this is the personal access token. For Bitbucket, this is the app password. .
        server_type(str):  The source provider used for this project. .
        auth_type(str):  The type of authentication used to connect to a GitHub, GitHub Enterprise, or Bitbucket repository. An OAUTH connection is not supported by the API and must be created using the AWS CodeBuild console. .
        should_overwrite(bool, optional):  Set to false to prevent overwriting the repository source credentials. Set to true to overwrite the repository source credentials. The default value is true. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.source_credential.import(ctx, token=value, server_type=value, auth_type=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.source_credential.import token=value, server_type=value, auth_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codebuild",
        operation="import_source_credentials",
        op_kwargs={
            "username": username,
            "token": token,
            "serverType": server_type,
            "authType": auth_type,
            "shouldOverwrite": should_overwrite,
        },
    )


async def list_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of SourceCredentialsInfo objects.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codebuild.source_credential.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codebuild.source_credential.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="codebuild", operation="list_source_credentials", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str,
    source_type: str = None,
    source_ids: List = None,
    event_categories: List = None,
    severity: str = None,
    enabled: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon Redshift event notification subscription. This action requires an ARN (Amazon Resource Name) of an Amazon SNS topic created by either the Amazon Redshift console, the Amazon SNS console, or the Amazon SNS API. To obtain an ARN with Amazon SNS, you must create a topic in Amazon SNS and subscribe to the topic. The ARN is displayed in the SNS console. You can specify the source type, and lists of Amazon Redshift source IDs, event categories, and event severities. Notifications will be sent for all events you want that match those criteria. For example, you can specify source type = cluster, source ID = my-cluster-1 and mycluster2, event categories = Availability, Backup, and severity = ERROR. The subscription will only send notifications for those ERROR events in the Availability and Backup categories for the specified clusters. If you specify both the source type and source IDs, such as source type = cluster and source identifier = my-cluster-1, notifications will be sent for all the cluster events for my-cluster-1. If you specify a source type but do not specify a source identifier, you will receive notice of the events for the objects of that type in your Amazon Web Services account. If you do not specify either the SourceType nor the SourceIdentifier, you will be notified of events generated from all Amazon Redshift sources belonging to your Amazon Web Services account. You must specify a source type if you specify a source ID.

    Args:
        subscription_name(str): The name of the event subscription to be created. Constraints:   Cannot be null, empty, or blank.   Must contain from 1 to 255 alphanumeric characters or hyphens.   First character must be a letter.   Cannot end with a hyphen or contain two consecutive hyphens.  .
        sns_topic_arn(str): The Amazon Resource Name (ARN) of the Amazon SNS topic used to transmit the event notifications. The ARN is created by Amazon SNS when you create a topic and subscribe to it.
        source_type(str, optional): The type of source that will be generating the events. For example, if you want to be notified of events generated by a cluster, you would set this parameter to cluster. If this value is not specified, events are returned for all Amazon Redshift objects in your Amazon Web Services account. You must specify a source type in order to specify source IDs. Valid values: cluster, cluster-parameter-group, cluster-security-group, cluster-snapshot, and scheduled-action. Defaults to None.
        source_ids(List, optional): A list of one or more identifiers of Amazon Redshift source objects. All of the objects must be of the same type as was specified in the source type parameter. The event subscription will return only events generated by the specified objects. If not specified, then events are returned for all objects within the source type specified. Example: my-cluster-1, my-cluster-2 Example: my-snapshot-20131010. Defaults to None.
        event_categories(List, optional): Specifies the Amazon Redshift event categories to be published by the event notification subscription. Values: configuration, management, monitoring, security, pending. Defaults to None.
        severity(str, optional): Specifies the Amazon Redshift event severity to be published by the event notification subscription. Values: ERROR, INFO. Defaults to None.
        enabled(bool, optional): A boolean value; set to true to activate the subscription, and set to false to create the subscription but not activate it. . Defaults to None.
        tags(List, optional): A list of tag instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.event.subscription.create(
                ctx, subscription_name=value, sns_topic_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.event.subscription.create subscription_name=value, sns_topic_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="create_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "SourceIds": source_ids,
            "EventCategories": event_categories,
            "Severity": severity,
            "Enabled": enabled,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, subscription_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an Amazon Redshift event notification subscription.

    Args:
        subscription_name(str): The name of the Amazon Redshift event notification subscription to be deleted.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.event.subscription.delete(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.event.subscription.delete subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="delete_event_subscription",
        op_kwargs={"SubscriptionName": subscription_name},
    )


async def describe_all(
    hub,
    ctx,
    subscription_name: str = None,
    max_records: int = None,
    marker: str = None,
    tag_keys: List = None,
    tag_values: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists descriptions of all the Amazon Redshift event notification subscriptions for a customer account. If you specify a subscription name, lists the description for that subscription. If you specify both tag keys and tag values in the same request, Amazon Redshift returns all event notification subscriptions that match any combination of the specified keys and values. For example, if you have owner and environment for tag keys, and admin and test for tag values, all subscriptions that have any combination of those values are returned. If both tag keys and values are omitted from the request, subscriptions are returned regardless of whether they have tag keys or values associated with them.

    Args:
        subscription_name(str, optional): The name of the Amazon Redshift event notification subscription to be described. Defaults to None.
        max_records(int, optional): The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.  Default: 100  Constraints: minimum 20, maximum 100. Defaults to None.
        marker(str, optional): An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeEventSubscriptions request exceed the value specified in MaxRecords, Amazon Web Services returns a value in the Marker field of the response. You can retrieve the next set of response records by providing the returned marker value in the Marker parameter and retrying the request. . Defaults to None.
        tag_keys(List, optional): A tag key or keys for which you want to return all matching event notification subscriptions that are associated with the specified key or keys. For example, suppose that you have subscriptions that are tagged with keys called owner and environment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag keys associated with them. Defaults to None.
        tag_values(List, optional): A tag value or values for which you want to return all matching event notification subscriptions that are associated with the specified tag value or values. For example, suppose that you have subscriptions that are tagged with values called admin and test. If you specify both of these tag values in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag values associated with them. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.event.subscription.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.event.subscription.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="describe_event_subscriptions",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "MaxRecords": max_records,
            "Marker": marker,
            "TagKeys": tag_keys,
            "TagValues": tag_values,
        },
    )


async def modify(
    hub,
    ctx,
    subscription_name: str,
    sns_topic_arn: str = None,
    source_type: str = None,
    source_ids: List = None,
    event_categories: List = None,
    severity: str = None,
    enabled: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an existing Amazon Redshift event notification subscription.

    Args:
        subscription_name(str): The name of the modified Amazon Redshift event notification subscription.
        sns_topic_arn(str, optional): The Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription. Defaults to None.
        source_type(str, optional): The type of source that will be generating the events. For example, if you want to be notified of events generated by a cluster, you would set this parameter to cluster. If this value is not specified, events are returned for all Amazon Redshift objects in your Amazon Web Services account. You must specify a source type in order to specify source IDs. Valid values: cluster, cluster-parameter-group, cluster-security-group, cluster-snapshot, and scheduled-action. Defaults to None.
        source_ids(List, optional): A list of one or more identifiers of Amazon Redshift source objects. All of the objects must be of the same type as was specified in the source type parameter. The event subscription will return only events generated by the specified objects. If not specified, then events are returned for all objects within the source type specified. Example: my-cluster-1, my-cluster-2 Example: my-snapshot-20131010. Defaults to None.
        event_categories(List, optional): Specifies the Amazon Redshift event categories to be published by the event notification subscription. Values: configuration, management, monitoring, security, pending. Defaults to None.
        severity(str, optional): Specifies the Amazon Redshift event severity to be published by the event notification subscription. Values: ERROR, INFO. Defaults to None.
        enabled(bool, optional): A Boolean value indicating if the subscription is enabled. true indicates the subscription is enabled . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.redshift.event.subscription.modify(ctx, subscription_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.redshift.event.subscription.modify subscription_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="redshift",
        operation="modify_event_subscription",
        op_kwargs={
            "SubscriptionName": subscription_name,
            "SnsTopicArn": sns_topic_arn,
            "SourceType": source_type,
            "SourceIds": source_ids,
            "EventCategories": event_categories,
            "Severity": severity,
            "Enabled": enabled,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, organization_id: str, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Requests a user's mailbox details for a specified organization and user.

    Args:
        organization_id(str): The identifier for the organization that contains the user whose mailbox details are being requested.
        user_id(str): The identifier for the user whose mailbox details are being requested.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.mailbox.detail.get_all(
                ctx, organization_id=value, user_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.mailbox.detail.get_all organization_id=value, user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="get_mailbox_details",
        op_kwargs={"OrganizationId": organization_id, "UserId": user_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(hub, ctx, detector_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates the current GuardDuty member account from its administrator account.

    Args:
        detector_id(str): The unique ID of the detector of the GuardDuty member account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.from_master_account.disassociate(
                ctx, detector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.from_master_account.disassociate detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="disassociate_from_master_account",
        op_kwargs={"DetectorId": detector_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    job_id: str,
    max_results: int = None,
    next_token: str = None,
    sort_by: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the path tracking results of a Amazon Rekognition Video analysis started by StartPersonTracking. The person path tracking operation is started by a call to StartPersonTracking which returns a job identifier (JobId). When the operation finishes, Amazon Rekognition Video publishes a completion status to the Amazon Simple Notification Service topic registered in the initial call to StartPersonTracking. To get the results of the person path tracking operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetPersonTracking and pass the job identifier (JobId) from the initial call to StartPersonTracking.  GetPersonTracking returns an array, Persons, of tracked persons and the time(s) their paths were tracked in the video.    GetPersonTracking only returns the default facial attributes (BoundingBox, Confidence, Landmarks, Pose, and Quality). The other facial attributes listed in the Face object of the following response syntax are not returned.  For more information, see FaceDetail in the Amazon Rekognition Developer Guide.  By default, the array is sorted by the time(s) a person's path is tracked in the video. You can sort by tracked persons by specifying INDEX for the SortBy input parameter. Use the MaxResults parameter to limit the number of items returned. If there are more results than specified in MaxResults, the value of NextToken in the operation response contains a pagination token for getting the next set of results. To get the next page of results, call GetPersonTracking and populate the NextToken request parameter with the token value returned from the previous call to GetPersonTracking.

    Args:
        job_id(str): The identifier for a job that tracks persons in a video. You get the JobId from a call to StartPersonTracking. .
        max_results(int, optional): Maximum number of results to return per paginated call. The largest value you can specify is 1000. If you specify a value greater than 1000, a maximum of 1000 results is returned. The default value is 1000. Defaults to None.
        next_token(str, optional): If the previous response was incomplete (because there are more persons to retrieve), Amazon Rekognition Video returns a pagination token in the response. You can use this pagination token to retrieve the next set of persons. . Defaults to None.
        sort_by(str, optional): Sort to use for elements in the Persons array. Use TIMESTAMP to sort array elements by the time persons are detected. Use INDEX to sort by the tracked persons. If you sort by INDEX, the array elements for each person are sorted by detection confidence. The default sort is by TIMESTAMP. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.person_tracking.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.person_tracking.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="get_person_tracking",
        op_kwargs={
            "JobId": job_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "SortBy": sort_by,
        },
    )


async def start(
    hub,
    ctx,
    video: Dict,
    client_request_token: str = None,
    notification_channel: Dict = None,
    job_tag: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the asynchronous tracking of a person's path in a stored video. Amazon Rekognition Video can track the path of people in a video stored in an Amazon S3 bucket. Use Video to specify the bucket name and the filename of the video. StartPersonTracking returns a job identifier (JobId) which you use to get the results of the operation. When label detection is finished, Amazon Rekognition publishes a completion status to the Amazon Simple Notification Service topic that you specify in NotificationChannel.  To get the results of the person detection operation, first check that the status value published to the Amazon SNS topic is SUCCEEDED. If so, call GetPersonTracking and pass the job identifier (JobId) from the initial call to StartPersonTracking.

    Args:
        video(Dict): The video in which you want to detect people. The video must be stored in an Amazon S3 bucket.
        client_request_token(str, optional): Idempotent token used to identify the start request. If you use the same token with multiple StartPersonTracking requests, the same JobId is returned. Use ClientRequestToken to prevent the same job from being accidently started more than once. . Defaults to None.
        notification_channel(Dict, optional): The Amazon SNS topic ARN you want Amazon Rekognition Video to publish the completion status of the people detection operation to. Defaults to None.
        job_tag(str, optional): An identifier you specify that's returned in the completion notification that's published to your Amazon Simple Notification Service topic. For example, you can use JobTag to group related jobs and identify them in the completion notification. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rekognition.person_tracking.start(ctx, video=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rekognition.person_tracking.start video=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rekognition",
        operation="start_person_tracking",
        op_kwargs={
            "Video": video,
            "ClientRequestToken": client_request_token,
            "NotificationChannel": notification_channel,
            "JobTag": job_tag,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    stack_name: str = None,
    user_name: str = None,
    authentication_type: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list that describes the UserStackAssociation objects. You must specify either or both of the following:   The stack name   The user name (email address of the user associated with the stack) and the authentication type for the user

    Args:
        stack_name(str, optional): The name of the stack that is associated with the user. Defaults to None.
        user_name(str, optional): The email address of the user who is associated with the stack.  Users' email addresses are case-sensitive. . Defaults to None.
        authentication_type(str, optional): The authentication type for the user who is associated with the stack. You must specify USERPOOL. Defaults to None.
        max_results(int, optional): The maximum size of each page of results. Defaults to None.
        next_token(str, optional): The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appstream.user.stack_association.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appstream.user.stack_association.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appstream",
        operation="describe_user_stack_associations",
        op_kwargs={
            "StackName": stack_name,
            "UserName": user_name,
            "AuthenticationType": authentication_type,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the ID of the certificate that is currently associated with a wireless gateway.

    Args:
        id_(str): The ID of the resource to get.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotwireless.wireless.gateway.certificate.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotwireless.wireless.gateway.certificate.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotwireless",
        operation="get_wireless_gateway_certificate",
        op_kwargs={"Id": id_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def batch(
    hub,
    ctx,
    index_id: str,
    document_id_list: List,
    data_source_sync_job_metric_target: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes one or more documents from an index. The documents must have been added with the BatchPutDocument operation. The documents are deleted asynchronously. You can see the progress of the deletion by using Amazon Web Services CloudWatch. Any error messages related to the processing of the batch are sent to you CloudWatch log.

    Args:
        index_id(str): The identifier of the index that contains the documents to delete.
        document_id_list(List): One or more identifiers for documents to delete from the index.
        data_source_sync_job_metric_target(Dict, optional): Maps a particular data source sync job to a particular data source. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.delete_document.batch(
                ctx, index_id=value, document_id_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.delete_document.batch index_id=value, document_id_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="batch_delete_document",
        op_kwargs={
            "IndexId": index_id,
            "DocumentIdList": document_id_list,
            "DataSourceSyncJobMetricTarget": data_source_sync_job_metric_target,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, organization_id: str, entity_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Mark a user, group, or resource as no longer used in Amazon WorkMail. This action disassociates the mailbox and schedules it for clean-up. WorkMail keeps mailboxes for 30 days before they are permanently removed. The functionality in the console is Disable.

    Args:
        organization_id(str): The identifier for the organization under which the Amazon WorkMail entity exists.
        entity_id(str): The identifier for the member (user or group) to be updated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workmail.from_work_mail.deregister(
                ctx, organization_id=value, entity_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workmail.from_work_mail.deregister organization_id=value, entity_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workmail",
        operation="deregister_from_work_mail",
        op_kwargs={"OrganizationId": organization_id, "EntityId": entity_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def associate(
    hub, ctx, approval_rule_template_name: str, repository_name: str
) -> None:
    r"""
    **Autogenerated function**

    Creates an association between an approval rule template and a specified repository. Then, the next time a pull request is created in the repository where the destination reference (if specified) matches the destination reference (branch) for the pull request, an approval rule that matches the template conditions is automatically created for that pull request. If no destination references are specified in the template, an approval rule that matches the template contents is created for all pull requests in that repository.

    Args:
        approval_rule_template_name(str): The name for the approval rule template. .
        repository_name(str): The name of the repository that you want to associate with the template.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codecommit.approval_rule_template.with_repository.associate(
                ctx, approval_rule_template_name=value, repository_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codecommit.approval_rule_template.with_repository.associate approval_rule_template_name=value, repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codecommit",
        operation="associate_approval_rule_template_with_repository",
        op_kwargs={
            "approvalRuleTemplateName": approval_rule_template_name,
            "repositoryName": repository_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    user_name: str,
    path: str = None,
    permissions_boundary: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new IAM user for your account.  For information about quotas for the number of IAM users you can create, see IAM and STS quotas in the IAM User Guide.

    Args:
        path(str, optional):  The path for the user name. For more information about paths, see IAM identifiers in the IAM User Guide. This parameter is optional. If it is not included, it defaults to a slash (/). This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        user_name(str): The name of the user to create. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource".
        permissions_boundary(str, optional): The ARN of the policy that is used to set the permissions boundary for the user. Defaults to None.
        tags(List, optional): A list of tags that you want to attach to the new user. Each tag consists of a key name and an associated value. For more information about tagging, see Tagging IAM resources in the IAM User Guide.  If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.create(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.create user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_user",
        op_kwargs={
            "Path": path,
            "UserName": user_name,
            "PermissionsBoundary": permissions_boundary,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, user_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified IAM user. Unlike the Management Console, when you delete a user programmatically, you must delete the items attached to the user manually, or the deletion fails. For more information, see Deleting an IAM user. Before attempting to delete a user, remove the following items:   Password (DeleteLoginProfile)   Access keys (DeleteAccessKey)   Signing certificate (DeleteSigningCertificate)   SSH public key (DeleteSSHPublicKey)   Git credentials (DeleteServiceSpecificCredential)   Multi-factor authentication (MFA) device (DeactivateMFADevice, DeleteVirtualMFADevice)   Inline policies (DeleteUserPolicy)   Attached managed policies (DetachUserPolicy)   Group memberships (RemoveUserFromGroup)

    Args:
        user_name(str): The name of the user to delete. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.delete(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.delete user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_user",
        op_kwargs={"UserName": user_name},
    )


async def get(hub, ctx, user_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified IAM user, including the user's creation date, path, unique ID, and ARN. If you do not specify a user name, IAM determines the user name implicitly based on the Amazon Web Services access key ID used to sign the request to this operation.

    Args:
        user_name(str, optional): The name of the user to get information about. This parameter is optional. If it is not included, it defaults to the user making the request. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iam", operation="get_user", op_kwargs={"UserName": user_name}
    )


async def list_all(
    hub, ctx, path_prefix: str = None, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IAM users that have the specified path prefix. If no path prefix is specified, the operation returns all users in the account. If there are none, the operation returns an empty list.  IAM resource-listing operations return a subset of the available attributes for the resource. For example, this operation does not return tags, even though they are an attribute of the returned object. To view all of the information for a user, see GetUser.  You can paginate the results using the MaxItems and Marker parameters.

    Args:
        path_prefix(str, optional):  The path prefix for filtering the results. For example: /division_abc/subdivision_xyz/, which would get all user names whose path starts with /division_abc/subdivision_xyz/. This parameter is optional. If it is not included, it defaults to a slash (/), listing all user names. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_users",
        op_kwargs={"PathPrefix": path_prefix, "Marker": marker, "MaxItems": max_items},
    )


async def tag(hub, ctx, user_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds one or more tags to an IAM user. If a tag with the same key name already exists, then that tag is overwritten with the new value. A tag consists of a key name and an associated value. By assigning tags to your resources, you can do the following:    Administrative grouping and discovery - Attach tags to resources to aid in organization and search. For example, you could search for all resources with the key name Project and the value MyImportantProject. Or search for all resources with the key name Cost Center and the value 41200.     Access control - Include tags in IAM user-based and resource-based policies. You can use tags to restrict access to only an IAM requesting user that has a specified tag attached. You can also restrict access to only those resources that have a certain tag attached. For examples of policies that show how to use tags to control access, see Control access using IAM tags in the IAM User Guide.    Cost allocation - Use tags to help track which individuals and teams are using which Amazon Web Services resources.      If any one of the tags is invalid or if you exceed the allowed maximum number of tags, then the entire request fails and the resource is not created. For more information about tagging, see Tagging IAM resources in the IAM User Guide.   Amazon Web Services always interprets the tag Value as a single string. If you need to store an array, you can store comma-separated values in the string. However, you must interpret the value in your code.    For more information about tagging, see Tagging IAM identities in the IAM User Guide.

    Args:
        user_name(str): The name of the IAM user to which you want to add tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tags(List): The list of tags that you want to attach to the IAM user. Each tag consists of a key name and an associated value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.tag(ctx, user_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.tag user_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="tag_user",
        op_kwargs={"UserName": user_name, "Tags": tags},
    )


async def untag(hub, ctx, user_name: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Removes the specified tags from the user. For more information about tagging, see Tagging IAM resources in the IAM User Guide.

    Args:
        user_name(str): The name of the IAM user from which you want to remove tags. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        tag_keys(List): A list of key names as a simple array of strings. The tags with matching keys are removed from the specified user.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.untag(ctx, user_name=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.untag user_name=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="untag_user",
        op_kwargs={"UserName": user_name, "TagKeys": tag_keys},
    )


async def update(
    hub, ctx, user_name: str, new_path: str = None, new_user_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Updates the name and/or the path of the specified IAM user.   You should understand the implications of changing an IAM user's path or name. For more information, see Renaming an IAM user and Renaming an IAM group in the IAM User Guide.    To change a user name, the requester must have appropriate permissions on both the source object and the target object. For example, to change Bob to Robert, the entity making the request must have permission on Bob and Robert, or must have permission on all (*). For more information about permissions, see Permissions and policies.

    Args:
        user_name(str): Name of the user to update. If you're changing the name of the user, this is the original user name. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        new_path(str, optional): New path for the IAM user. Include this parameter only if you're changing the user's path. This parameter allows (through its regex pattern) a string of characters consisting of either a forward slash (/) by itself or a string that must begin and end with forward slashes. In addition, it can contain any ASCII character from the ! (\u0021) through the DEL character (\u007F), including most punctuation characters, digits, and upper and lowercased letters. Defaults to None.
        new_user_name(str, optional): New name for the user. Include this parameter only if you're changing the user's name. IAM user, group, role, and policy names must be unique within the account. Names are not distinguished by case. For example, you cannot create resources named both "MyResource" and "myresource". Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.user.init.update(ctx, user_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.user.init.update user_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_user",
        op_kwargs={
            "UserName": user_name,
            "NewPath": new_path,
            "NewUserName": new_user_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, ml_model_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a real-time endpoint for the MLModel. The endpoint contains the URI of the MLModel; that is, the location to send real-time prediction requests for the specified MLModel.

    Args:
        ml_model_id(str): The ID assigned to the MLModel during creation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.realtime_endpoint.create(ctx, ml_model_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.realtime_endpoint.create ml_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="create_realtime_endpoint",
        op_kwargs={"MLModelId": ml_model_id},
    )


async def delete(hub, ctx, ml_model_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a real time endpoint of an MLModel.

    Args:
        ml_model_id(str): The ID assigned to the MLModel during creation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.machinelearning.realtime_endpoint.delete(ctx, ml_model_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.machinelearning.realtime_endpoint.delete ml_model_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="machinelearning",
        operation="delete_realtime_endpoint",
        op_kwargs={"MLModelId": ml_model_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, type_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the specified limit for the current account, for example, the maximum number of health checks that you can create using the account. For the default limit, see Limits in the Amazon Route 53 Developer Guide. To request a higher limit, open a case.  You can also view account limits in Amazon Web Services Trusted Advisor. Sign in to the Management Console and open the Trusted Advisor console at https://console.aws.amazon.com/trustedadvisor/. Then choose Service limits in the navigation pane.

    Args:
        type_(str): The limit that you want to get. Valid values include the following:    MAX_HEALTH_CHECKS_BY_OWNER: The maximum number of health checks that you can create using the current account.    MAX_HOSTED_ZONES_BY_OWNER: The maximum number of hosted zones that you can create using the current account.    MAX_REUSABLE_DELEGATION_SETS_BY_OWNER: The maximum number of reusable delegation sets that you can create using the current account.    MAX_TRAFFIC_POLICIES_BY_OWNER: The maximum number of traffic policies that you can create using the current account.    MAX_TRAFFIC_POLICY_INSTANCES_BY_OWNER: The maximum number of traffic policy instances that you can create using the current account. (Traffic policy instances are referred to as traffic flow policy records in the Amazon Route 53 console.)  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.account_limit.get(ctx, type_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.account_limit.get type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_account_limit",
        op_kwargs={"Type": type_},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, application: str, resource_type: str, resource: str
) -> Dict:
    r"""
    **Autogenerated function**

    Associates a resource with an application. Both the resource and the application can be specified either by ID or name.

    Args:
        application(str): The name or ID of the application.
        resource_type(str): The type of resource of which the application will be associated.
        resource(str): The name or ID of the resource of which the application will be associated.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.resource.associate(
                ctx, application=value, resource_type=value, resource=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.resource.associate application=value, resource_type=value, resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="associate_resource",
        op_kwargs={
            "application": application,
            "resourceType": resource_type,
            "resource": resource,
        },
    )


async def disassociate(
    hub, ctx, application: str, resource_type: str, resource: str
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a resource from application. Both the resource and the application can be specified either by ID or name.

    Args:
        application(str): The name or ID of the application.
        resource_type(str): The type of the resource that is being disassociated.
        resource(str): The name or ID of the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.resource.disassociate(
                ctx, application=value, resource_type=value, resource=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.resource.disassociate application=value, resource_type=value, resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="disassociate_resource",
        op_kwargs={
            "application": application,
            "resourceType": resource_type,
            "resource": resource,
        },
    )


async def sync(hub, ctx, resource_type: str, resource: str) -> Dict:
    r"""
    **Autogenerated function**

    Syncs the resource with what is currently recorded in App registry. Specifically, the resource’s App registry system tags are synced with its associated application. The resource is removed if it is not associated with the application. The caller must have permissions to read and update the resource.

    Args:
        resource_type(str): The type of resource of which the application will be associated.
        resource(str): An entity you can work with and specify with a name or ID. Examples include an Amazon EC2 instance, an AWS CloudFormation stack, or an Amazon S3 bucket.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.resource.sync(
                ctx, resource_type=value, resource=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.resource.sync resource_type=value, resource=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="sync_resource",
        op_kwargs={"resourceType": resource_type, "resource": resource},
    )


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Assigns one or more tags (key-value pairs) to the specified resource. Each tag consists of a key and an optional value. If a tag with the same key is already associated with the resource, this action updates its value. This operation returns an empty response if the call was successful.

    Args:
        resource_arn(str): The Amazon resource name (ARN) that specifies the resource.
        tags(Dict): The new or modified tags for the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.resource.tag(
                ctx, resource_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Removes tags from a resource. This operation returns an empty response if the call was successful.

    Args:
        resource_arn(str): The Amazon resource name (ARN) that specifies the resource.
        tag_keys(List): A list of the tag keys to remove from the specified resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog_appregistry.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog_appregistry.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog-appregistry",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "aggregate_id_format"


async def describe(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the longer ID format settings for all resource types in a specific Region. This request is useful for performing a quick audit to determine whether a specific Region is fully opted in for longer IDs (17-character IDs). This request only returns information about resource types that support longer IDs. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.aggregate_id_format_.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.aggregate_id_format.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_aggregate_id_format",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    id_: str,
    index_id: str,
    next_token: str = None,
    max_results: int = None,
    start_time_filter: Dict = None,
    status_filter: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets statistics about synchronizing Amazon Kendra with a data source.

    Args:
        id_(str): The identifier of the data source.
        index_id(str): The identifier of the index that contains the data source.
        next_token(str, optional): If the result of the previous request to GetDataSourceSyncJobHistory was truncated, include the NextToken to fetch the next set of jobs. Defaults to None.
        max_results(int, optional): The maximum number of synchronization jobs to return in the response. If there are fewer results in the list, this response contains only the actual results. Defaults to None.
        start_time_filter(Dict, optional): When specified, the synchronization jobs returned in the list are limited to jobs between the specified dates. . Defaults to None.
        status_filter(str, optional): When specified, only returns synchronization jobs with the Status field equal to the specified status. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.sync_job.list_all(
                ctx, id_=value, index_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.sync_job.list_all id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="list_data_source_sync_jobs",
        op_kwargs={
            "Id": id_,
            "IndexId": index_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "StartTimeFilter": start_time_filter,
            "StatusFilter": status_filter,
        },
    )


async def start(hub, ctx, id_: str, index_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Starts a synchronization job for a data source. If a synchronization job is already in progress, Amazon Kendra returns a ResourceInUseException exception.

    Args:
        id_(str): The identifier of the data source to synchronize.
        index_id(str): The identifier of the index that contains the data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.sync_job.start(
                ctx, id_=value, index_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.sync_job.start id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="start_data_source_sync_job",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )


async def stop(hub, ctx, id_: str, index_id: str) -> None:
    r"""
    **Autogenerated function**

    Stops a running synchronization job. You can't stop a scheduled synchronization job.

    Args:
        id_(str): The identifier of the data source for which to stop the synchronization jobs.
        index_id(str): The identifier of the index that contains the data source.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.data_source.sync_job.stop(ctx, id_=value, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.data_source.sync_job.stop id_=value, index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="stop_data_source_sync_job",
        op_kwargs={"Id": id_, "IndexId": index_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    aws_account_id: str,
    dashboard_id: str,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the versions of the dashboards in the QuickSight subscription.

    Args:
        aws_account_id(str): The ID of the Amazon Web Services account; that contains the dashboard that you're listing versions for.
        dashboard_id(str): The ID for the dashboard.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        max_results(int, optional): The maximum number of results to be returned per request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.quicksight.dashboard.version.list_all(
                ctx, aws_account_id=value, dashboard_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.quicksight.dashboard.version.list_all aws_account_id=value, dashboard_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="quicksight",
        operation="list_dashboard_versions",
        op_kwargs={
            "AwsAccountId": aws_account_id,
            "DashboardId": dashboard_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    security_profile_name: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a Device Defender's ML Detect Security Profile training model's status.

    Args:
        security_profile_name(str, optional):  The name of the security profile. . Defaults to None.
        max_results(int, optional):  The maximum number of results to return at one time. The default is 25. . Defaults to None.
        next_token(str, optional):  The token for the next set of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.behavior_model_training_summary.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.behavior_model_training_summary.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_behavior_model_training_summaries",
        op_kwargs={
            "securityProfileName": security_profile_name,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    continent_code: str = None,
    country_code: str = None,
    subdivision_code: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about whether a specified geographic location is supported for Amazon Route 53 geolocation resource record sets. Route 53 does not perform authorization for this API because it retrieves information that is already available to the public. Use the following syntax to determine whether a continent is supported for geolocation:  GET /2013-04-01/geolocation?continentcode=two-letter abbreviation for a continent   Use the following syntax to determine whether a country is supported for geolocation:  GET /2013-04-01/geolocation?countrycode=two-character country code   Use the following syntax to determine whether a subdivision of a country is supported for geolocation:  GET /2013-04-01/geolocation?countrycode=two-character country code&subdivisioncode=subdivision code

    Args:
        continent_code(str, optional): For geolocation resource record sets, a two-letter abbreviation that identifies a continent. Amazon Route 53 supports the following continent codes:    AF: Africa    AN: Antarctica    AS: Asia    EU: Europe    OC: Oceania    NA: North America    SA: South America  . Defaults to None.
        country_code(str, optional): Amazon Route 53 uses the two-letter country codes that are specified in ISO standard 3166-1 alpha-2. Defaults to None.
        subdivision_code(str, optional): The code for the subdivision, such as a particular state within the United States. For a list of US state abbreviations, see Appendix B: Two–Letter State and Possession Abbreviations on the United States Postal Service website. For a list of all supported subdivision codes, use the ListGeoLocations API. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.geo_location.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.geo_location.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="get_geo_location",
        op_kwargs={
            "ContinentCode": continent_code,
            "CountryCode": country_code,
            "SubdivisionCode": subdivision_code,
        },
    )


async def list_all(
    hub,
    ctx,
    start_continent_code: str = None,
    start_country_code: str = None,
    start_subdivision_code: str = None,
    max_items: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a list of supported geographic locations. Countries are listed first, and continents are listed last. If Amazon Route 53 supports subdivisions for a country (for example, states or provinces), the subdivisions for that country are listed in alphabetical order immediately after the corresponding country. Route 53 does not perform authorization for this API because it retrieves information that is already available to the public. For a list of supported geolocation codes, see the GeoLocation data type.

    Args:
        start_continent_code(str, optional): The code for the continent with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextContinentCode from the previous response has a value, enter that value in startcontinentcode to return the next page of results. Include startcontinentcode only if you want to list continents. Don't include startcontinentcode when you're listing countries or countries with their subdivisions. Defaults to None.
        start_country_code(str, optional): The code for the country with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextCountryCode from the previous response has a value, enter that value in startcountrycode to return the next page of results. Defaults to None.
        start_subdivision_code(str, optional): The code for the state of the United States with which you want to start listing locations that Amazon Route 53 supports for geolocation. If Route 53 has already returned a page or more of results, if IsTruncated is true, and if NextSubdivisionCode from the previous response has a value, enter that value in startsubdivisioncode to return the next page of results. To list subdivisions (U.S. states), you must include both startcountrycode and startsubdivisioncode. Defaults to None.
        max_items(str, optional): (Optional) The maximum number of geolocations to be included in the response body for this request. If more than maxitems geolocations remain to be listed, then the value of the IsTruncated element in the response is true. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53.geo_location.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53.geo_location.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53",
        operation="list_geo_locations",
        op_kwargs={
            "StartContinentCode": start_continent_code,
            "StartCountryCode": start_country_code,
            "StartSubdivisionCode": start_subdivision_code,
            "MaxItems": max_items,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, table_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Checks the status of continuous backups and point in time recovery on the specified table. Continuous backups are ENABLED on all tables at table creation. If point in time recovery is enabled, PointInTimeRecoveryStatus will be set to ENABLED.  After continuous backups and point in time recovery are enabled, you can restore to any point in time within EarliestRestorableDateTime and LatestRestorableDateTime.   LatestRestorableDateTime is typically 5 minutes before the current time. You can restore your table to any point in time during the last 35 days.  You can call DescribeContinuousBackups at a maximum rate of 10 times per second.

    Args:
        table_name(str): Name of the table for which the customer wants to check the continuous backups and point in time recovery settings.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.continuous_backup.describe_all(ctx, table_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.continuous_backup.describe_all table_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="describe_continuous_backups",
        op_kwargs={"TableName": table_name},
    )


async def update_multiple(
    hub, ctx, table_name: str, point_in_time_recovery_specification: Dict
) -> Dict:
    r"""
    **Autogenerated function**

     UpdateContinuousBackups enables or disables point in time recovery for the specified table. A successful UpdateContinuousBackups call returns the current ContinuousBackupsDescription. Continuous backups are ENABLED on all tables at table creation. If point in time recovery is enabled, PointInTimeRecoveryStatus will be set to ENABLED.  Once continuous backups and point in time recovery are enabled, you can restore to any point in time within EarliestRestorableDateTime and LatestRestorableDateTime.   LatestRestorableDateTime is typically 5 minutes before the current time. You can restore your table to any point in time during the last 35 days.

    Args:
        table_name(str): The name of the table.
        point_in_time_recovery_specification(Dict): Represents the settings used to enable point in time recovery.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodb.continuous_backup.update_multiple(
                ctx, table_name=value, point_in_time_recovery_specification=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodb.continuous_backup.update_multiple table_name=value, point_in_time_recovery_specification=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodb",
        operation="update_continuous_backups",
        op_kwargs={
            "TableName": table_name,
            "PointInTimeRecoverySpecification": point_in_time_recovery_specification,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"import_": "import"}


async def copy(
    hub,
    ctx,
    name: str,
    source_image_id: str,
    source_region: str,
    client_token: str = None,
    description: str = None,
    encrypted: bool = None,
    kms_key_id: str = None,
    destination_outpost_arn: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Initiates the copy of an AMI. You can copy an AMI from one Region to another, or from a Region to an AWS Outpost. You can't copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost. To copy an AMI to another partition, see CreateStoreImageTask. To copy an AMI from one Region to another, specify the source Region using the SourceRegion parameter, and specify the destination Region using its endpoint. Copies of encrypted backing snapshots for the AMI are encrypted. Copies of unencrypted backing snapshots remain unencrypted, unless you set Encrypted during the copy operation. You cannot create an unencrypted copy of an encrypted backing snapshot. To copy an AMI from a Region to an Outpost, specify the source Region using the SourceRegion parameter, and specify the ARN of the destination Outpost using DestinationOutpostArn. Backing snapshots copied to an Outpost are encrypted by default using the default encryption key for the Region, or a different key that you specify in the request using KmsKeyId. Outposts do not support unencrypted snapshots. For more information,  Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide. For more information about the prerequisites and limits when copying an AMI, see Copying an AMI in the Amazon Elastic Compute Cloud User Guide.

    Args:
        client_token(str, optional): Unique, case-sensitive identifier you provide to ensure idempotency of the request. For more information, see Ensuring idempotency in the Amazon EC2 API Reference. Defaults to None.
        description(str, optional): A description for the new AMI in the destination Region. Defaults to None.
        encrypted(bool, optional): Specifies whether the destination snapshots of the copied image should be encrypted. You can encrypt a copy of an unencrypted snapshot, but you cannot create an unencrypted copy of an encrypted snapshot. The default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using KmsKeyId. For more information, see Amazon EBS Encryption in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        kms_key_id(str, optional): The identifier of the symmetric AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating encrypted volumes. If this parameter is not specified, your AWS managed CMK for EBS is used. If you specify a CMK, you must also set the encrypted state to true. You can specify a CMK using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   AWS authenticates the CMK asynchronously. Therefore, if you specify an identifier that is not valid, the action can appear to complete, but eventually fails. The specified CMK must exist in the destination Region. Amazon EBS does not support asymmetric CMKs. Defaults to None.
        name(str): The name of the new AMI in the destination Region.
        source_image_id(str): The ID of the AMI to copy.
        source_region(str): The name of the Region that contains the AMI to copy.
        destination_outpost_arn(str, optional): The Amazon Resource Name (ARN) of the Outpost to which to copy the AMI. Only specify this parameter when copying an AMI from an AWS Region to an Outpost. The AMI must be in the Region of the destination Outpost. You cannot copy an AMI from an Outpost to a Region, from one Outpost to another, or within the same Outpost. For more information, see  Copying AMIs from an AWS Region to an Outpost in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.copy(ctx, name=value, source_image_id=value, source_region=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.copy name=value, source_image_id=value, source_region=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="copy_image",
        op_kwargs={
            "ClientToken": client_token,
            "Description": description,
            "Encrypted": encrypted,
            "KmsKeyId": kms_key_id,
            "Name": name,
            "SourceImageId": source_image_id,
            "SourceRegion": source_region,
            "DestinationOutpostArn": destination_outpost_arn,
            "DryRun": dry_run,
        },
    )


async def create(
    hub,
    ctx,
    instance_id: str,
    name: str,
    block_device_mappings: List = None,
    description: str = None,
    dry_run: bool = None,
    no_reboot: bool = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an Amazon EBS-backed AMI from an Amazon EBS-backed instance that is either running or stopped. If you customized your instance with instance store volumes or EBS volumes in addition to the root device volume, the new AMI contains block device mapping information for those volumes. When you launch an instance from this new AMI, the instance automatically launches with those additional volumes. For more information, see Creating Amazon EBS-Backed Linux AMIs in the Amazon Elastic Compute Cloud User Guide.

    Args:
        block_device_mappings(List, optional): The block device mappings. This parameter cannot be used to modify the encryption status of existing volumes or snapshots. To create an AMI with encrypted snapshots, use the CopyImage action. Defaults to None.
        description(str, optional): A description for the new image. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.
        name(str): A name for the new image. Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_).
        no_reboot(bool, optional): By default, Amazon EC2 attempts to shut down and reboot the instance before creating the image. If the No Reboot option is set, Amazon EC2 doesn't shut down the instance before creating the image. When this option is used, file system integrity on the created image can't be guaranteed. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the AMI and snapshots on creation. You can tag the AMI, the snapshots, or both.   To tag the AMI, the value for ResourceType must be image.   To tag the snapshots that are created of the root volume and of other EBS volumes that are attached to the instance, the value for ResourceType must be snapshot. The same tag is applied to all of the snapshots that are created.   If you specify other values for ResourceType, the request fails. To tag an AMI or snapshot after it has been created, see CreateTags. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.create(ctx, instance_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.create instance_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_image",
        op_kwargs={
            "BlockDeviceMappings": block_device_mappings,
            "Description": description,
            "DryRun": dry_run,
            "InstanceId": instance_id,
            "Name": name,
            "NoReboot": no_reboot,
            "TagSpecifications": tag_specifications,
        },
    )


async def deregister(hub, ctx, image_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deregisters the specified AMI. After you deregister an AMI, it can't be used to launch new instances; however, it doesn't affect any instances that you've already launched from the AMI. You'll continue to incur usage costs for those instances until you terminate them. When you deregister an Amazon EBS-backed AMI, it doesn't affect the snapshot that was created for the root volume of the instance during the AMI creation process. When you deregister an instance store-backed AMI, it doesn't affect the files that you uploaded to Amazon S3 when you created the AMI.

    Args:
        image_id(str): The ID of the AMI.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.deregister(ctx, image_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.deregister image_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="deregister_image",
        op_kwargs={"ImageId": image_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    executable_users: List = None,
    filters: List = None,
    image_ids: List = None,
    owners: List = None,
    include_deprecated: bool = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified images (AMIs, AKIs, and ARIs) available to you or all of the images available to you. The images available to you include public images, private images that you own, and private images owned by other AWS accounts for which you have explicit launch permissions. Recently deregistered images appear in the returned results for a short interval and then return empty results. After all instances that reference a deregistered AMI are terminated, specifying the ID of the image will eventually return an error indicating that the AMI ID cannot be found.

    Args:
        executable_users(List, optional): Scopes the images by users with explicit launch permissions. Specify an AWS account ID, self (the sender of the request), or all (public AMIs). Defaults to None.
        filters(List, optional): The filters.    architecture - The image architecture (i386 | x86_64 | arm64).    block-device-mapping.delete-on-termination - A Boolean value that indicates whether the Amazon EBS volume is deleted on instance termination.    block-device-mapping.device-name - The device name specified in the block device mapping (for example, /dev/sdh or xvdh).    block-device-mapping.snapshot-id - The ID of the snapshot used for the EBS volume.    block-device-mapping.volume-size - The volume size of the EBS volume, in GiB.    block-device-mapping.volume-type - The volume type of the EBS volume (gp2 | io1 | io2 | st1 | sc1 | standard).    block-device-mapping.encrypted - A Boolean that indicates whether the EBS volume is encrypted.    description - The description of the image (provided during image creation).    ena-support - A Boolean that indicates whether enhanced networking with ENA is enabled.    hypervisor - The hypervisor type (ovm | xen).    image-id - The ID of the image.    image-type - The image type (machine | kernel | ramdisk).    is-public - A Boolean that indicates whether the image is public.    kernel-id - The kernel ID.    manifest-location - The location of the image manifest.    name - The name of the AMI (provided during image creation).    owner-alias - The owner alias (amazon | aws-marketplace). The valid aliases are defined in an Amazon-maintained list. This is not the AWS account alias that can be set using the IAM console. We recommend that you use the Owner request parameter instead of this filter.    owner-id - The AWS account ID of the owner. We recommend that you use the Owner request parameter instead of this filter.    platform - The platform. To only list Windows-based AMIs, use windows.    product-code - The product code.    product-code.type - The type of the product code (devpay | marketplace).    ramdisk-id - The RAM disk ID.    root-device-name - The device name of the root device volume (for example, /dev/sda1).    root-device-type - The type of the root device volume (ebs | instance-store).    state - The state of the image (available | pending | failed).    state-reason-code - The reason code for the state change.    state-reason-message - The message for the state change.    sriov-net-support - A value of simple indicates that enhanced networking with the Intel 82599 VF interface is enabled.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    virtualization-type - The virtualization type (paravirtual | hvm).  . Defaults to None.
        image_ids(List, optional): The image IDs. Default: Describes all images available to you. Defaults to None.
        owners(List, optional): Scopes the results to images with the specified owners. You can specify a combination of AWS account IDs, self, amazon, and aws-marketplace. If you omit this parameter, the results include all images for which you have launch permissions, regardless of ownership. Defaults to None.
        include_deprecated(bool, optional): If true, all deprecated AMIs are included in the response. If false, no deprecated AMIs are included in the response. If no value is specified, the default value is false.  If you are the AMI owner, all deprecated AMIs appear in the response regardless of the value (true or false) that you set for this parameter. . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_images",
        op_kwargs={
            "ExecutableUsers": executable_users,
            "Filters": filters,
            "ImageIds": image_ids,
            "Owners": owners,
            "IncludeDeprecated": include_deprecated,
            "DryRun": dry_run,
        },
    )


async def export(
    hub,
    ctx,
    disk_image_format: str,
    image_id: str,
    s3_export_location: Dict,
    client_token: str = None,
    description: str = None,
    dry_run: bool = None,
    role_name: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Exports an Amazon Machine Image (AMI) to a VM file. For more information, see Exporting a VM directly from an Amazon Machine Image (AMI) in the VM Import/Export User Guide.

    Args:
        client_token(str, optional): Token to enable idempotency for export image requests. Defaults to None.
        description(str, optional): A description of the image being exported. The maximum length is 255 characters. Defaults to None.
        disk_image_format(str): The disk image format.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        image_id(str): The ID of the image.
        s3_export_location(Dict): Information about the destination Amazon S3 bucket. The bucket must exist and grant WRITE and READ_ACP permissions to the AWS account vm-import-export@amazon.com.
        role_name(str, optional): The name of the role that grants VM Import/Export permission to export images to your Amazon S3 bucket. If this parameter is not specified, the default role is named 'vmimport'. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the export image task during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.export(ctx, disk_image_format=value, image_id=value, s3_export_location=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.export disk_image_format=value, image_id=value, s3_export_location=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="export_image",
        op_kwargs={
            "ClientToken": client_token,
            "Description": description,
            "DiskImageFormat": disk_image_format,
            "DryRun": dry_run,
            "ImageId": image_id,
            "S3ExportLocation": s3_export_location,
            "RoleName": role_name,
            "TagSpecifications": tag_specifications,
        },
    )


async def import_(
    hub,
    ctx,
    architecture: str = None,
    client_data: Dict = None,
    client_token: str = None,
    description: str = None,
    disk_containers: List = None,
    dry_run: bool = None,
    encrypted: bool = None,
    hypervisor: str = None,
    kms_key_id: str = None,
    license_type: str = None,
    platform: str = None,
    role_name: str = None,
    license_specifications: List = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Import single or multi-volume disk images or EBS snapshots into an Amazon Machine Image (AMI). For more information, see Importing a VM as an image using VM Import/Export in the VM Import/Export User Guide.

    Args:
        architecture(str, optional): The architecture of the virtual machine. Valid values: i386 | x86_64 | arm64 . Defaults to None.
        client_data(Dict, optional): The client-specific data. Defaults to None.
        client_token(str, optional): The token to enable idempotency for VM import requests. Defaults to None.
        description(str, optional): A description string for the import image task. Defaults to None.
        disk_containers(List, optional): Information about the disk containers. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        encrypted(bool, optional): Specifies whether the destination AMI of the imported image should be encrypted. The default CMK for EBS is used unless you specify a non-default AWS Key Management Service (AWS KMS) CMK using KmsKeyId. For more information, see Amazon EBS Encryption in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        hypervisor(str, optional): The target hypervisor platform. Valid values: xen . Defaults to None.
        kms_key_id(str, optional): An identifier for the symmetric AWS Key Management Service (AWS KMS) customer master key (CMK) to use when creating the encrypted AMI. This parameter is only required if you want to use a non-default CMK; if this parameter is not specified, the default CMK for EBS is used. If a KmsKeyId is specified, the Encrypted flag must also be set.  The CMK identifier may be provided in any of the following formats:    Key ID   Key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the CMK, the AWS account ID of the CMK owner, the alias namespace, and then the CMK alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   ARN using key ID. The ID ARN contains the arn:aws:kms namespace, followed by the Region of the CMK, the AWS account ID of the CMK owner, the key namespace, and then the CMK ID. For example, arn:aws:kms:us-east-1:012345678910:key/abcd1234-a123-456a-a12b-a123b4cd56ef.   ARN using key alias. The alias ARN contains the arn:aws:kms namespace, followed by the Region of the CMK, the AWS account ID of the CMK owner, the alias namespace, and then the CMK alias. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.    AWS parses KmsKeyId asynchronously, meaning that the action you call may appear to complete even though you provided an invalid identifier. This action will eventually report failure.  The specified CMK must exist in the Region that the AMI is being copied to. Amazon EBS does not support asymmetric CMKs. Defaults to None.
        license_type(str, optional): The license type to be used for the Amazon Machine Image (AMI) after importing. By default, we detect the source-system operating system (OS) and apply the appropriate license. Specify AWS to replace the source-system license with an AWS license, if appropriate. Specify BYOL to retain the source-system license, if appropriate. To use BYOL, you must have existing licenses with rights to use these licenses in a third party cloud, such as AWS. For more information, see Prerequisites in the VM Import/Export User Guide. Defaults to None.
        platform(str, optional): The operating system of the virtual machine. Valid values: Windows | Linux . Defaults to None.
        role_name(str, optional): The name of the role to use when not using the default role, 'vmimport'. Defaults to None.
        license_specifications(List, optional): The ARNs of the license configurations. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the import image task during creation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.import(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.import
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="import_image",
        op_kwargs={
            "Architecture": architecture,
            "ClientData": client_data,
            "ClientToken": client_token,
            "Description": description,
            "DiskContainers": disk_containers,
            "DryRun": dry_run,
            "Encrypted": encrypted,
            "Hypervisor": hypervisor,
            "KmsKeyId": kms_key_id,
            "LicenseType": license_type,
            "Platform": platform,
            "RoleName": role_name,
            "LicenseSpecifications": license_specifications,
            "TagSpecifications": tag_specifications,
        },
    )


async def register(
    hub,
    ctx,
    name: str,
    image_location: str = None,
    architecture: str = None,
    block_device_mappings: List = None,
    description: str = None,
    dry_run: bool = None,
    ena_support: bool = None,
    kernel_id: str = None,
    billing_products: List = None,
    ramdisk_id: str = None,
    root_device_name: str = None,
    sriov_net_support: str = None,
    virtualization_type: str = None,
    boot_mode: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Registers an AMI. When you're creating an AMI, this is the final step you must complete before you can launch an instance from the AMI. For more information about creating AMIs, see Creating your own AMIs in the Amazon Elastic Compute Cloud User Guide.  For Amazon EBS-backed instances, CreateImage creates and registers the AMI in a single request, so you don't have to register the AMI yourself.  If needed, you can deregister an AMI at any time. Any modifications you make to an AMI backed by an instance store volume invalidates its registration. If you make changes to an image, deregister the previous image and register the new image.  Register a snapshot of a root device volume  You can use RegisterImage to create an Amazon EBS-backed Linux AMI from a snapshot of a root device volume. You specify the snapshot using a block device mapping. You can't set the encryption state of the volume using the block device mapping. If the snapshot is encrypted, or encryption by default is enabled, the root volume of an instance launched from the AMI is encrypted. For more information, see Create a Linux AMI from a snapshot and Use encryption with EBS-backed AMIs in the Amazon Elastic Compute Cloud User Guide.  AWS Marketplace product codes  If any snapshots have AWS Marketplace product codes, they are copied to the new AMI. Windows and some Linux distributions, such as Red Hat Enterprise Linux (RHEL) and SUSE Linux Enterprise Server (SLES), use the EC2 billing product code associated with an AMI to verify the subscription status for package updates. To create a new AMI for operating systems that require a billing product code, instead of registering the AMI, do the following to preserve the billing product code association:   Launch an instance from an existing AMI with that billing product code.   Customize the instance.   Create an AMI from the instance using CreateImage.   If you purchase a Reserved Instance to apply to an On-Demand Instance that was launched from an AMI with a billing product code, make sure that the Reserved Instance has the matching billing product code. If you purchase a Reserved Instance without the matching billing product code, the Reserved Instance will not be applied to the On-Demand Instance. For information about how to obtain the platform details and billing information of an AMI, see Obtaining billing information in the Amazon Elastic Compute Cloud User Guide.

    Args:
        image_location(str, optional): The full path to your AMI manifest in Amazon S3 storage. The specified bucket must have the aws-exec-read canned access control list (ACL) to ensure that it can be accessed by Amazon EC2. For more information, see Canned ACLs in the Amazon S3 Service Developer Guide. Defaults to None.
        architecture(str, optional): The architecture of the AMI. Default: For Amazon EBS-backed AMIs, i386. For instance store-backed AMIs, the architecture specified in the manifest file. Defaults to None.
        block_device_mappings(List, optional): The block device mapping entries. If you specify an EBS volume using the ID of an EBS snapshot, you can't specify the encryption state of the volume. If you create an AMI on an Outpost, then all backing snapshots must be on the same Outpost or in the Region of that Outpost. AMIs on an Outpost that include local snapshots can be used to launch instances on the same Outpost only. For more information,  Amazon EBS local snapshots on Outposts in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        description(str, optional): A description for your AMI. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        ena_support(bool, optional): Set to true to enable enhanced networking with ENA for the AMI and any instances that you launch from the AMI. This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable. Defaults to None.
        kernel_id(str, optional): The ID of the kernel. Defaults to None.
        name(str): A name for your AMI. Constraints: 3-128 alphanumeric characters, parentheses (()), square brackets ([]), spaces ( ), periods (.), slashes (/), dashes (-), single quotes ('), at-signs (@), or underscores(_).
        billing_products(List, optional): The billing product codes. Your account must be authorized to specify billing product codes. Otherwise, you can use the AWS Marketplace to bill for the use of an AMI. Defaults to None.
        ramdisk_id(str, optional): The ID of the RAM disk. Defaults to None.
        root_device_name(str, optional): The device name of the root device volume (for example, /dev/sda1). Defaults to None.
        sriov_net_support(str, optional): Set to simple to enable enhanced networking with the Intel 82599 Virtual Function interface for the AMI and any instances that you launch from the AMI. There is no way to disable sriovNetSupport at this time. This option is supported only for HVM AMIs. Specifying this option with a PV AMI can make instances launched from the AMI unreachable. Defaults to None.
        virtualization_type(str, optional): The type of virtualization (hvm | paravirtual). Default: paravirtual . Defaults to None.
        boot_mode(str, optional): The boot mode of the AMI. For more information, see Boot modes in the Amazon Elastic Compute Cloud User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.image.init.register(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.image.init.register name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="register_image",
        op_kwargs={
            "ImageLocation": image_location,
            "Architecture": architecture,
            "BlockDeviceMappings": block_device_mappings,
            "Description": description,
            "DryRun": dry_run,
            "EnaSupport": ena_support,
            "KernelId": kernel_id,
            "Name": name,
            "BillingProducts": billing_products,
            "RamdiskId": ramdisk_id,
            "RootDeviceName": root_device_name,
            "SriovNetSupport": sriov_net_support,
            "VirtualizationType": virtualization_type,
            "BootMode": boot_mode,
        },
    )
